module.exports = defineTest({
	description: 'preserve common TDZ violations'
});
